==> java-sdk-1.0.0-20200710.110940-61-sources.jar: com/phonepe/sdk/javasdk/http/PhonePeHttpClientFactory.java <==
package com.phonepe.sdk.javasdk.http;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.google.common.base.Preconditions;
import com.phonepe.sdk.javasdk.config.models.HttpClientConfig;
import com.phonepe.sdk.javasdk.http.models.PhonePeHttpRequest;
import com.phonepe.sdk.javasdk.http.models.PhonePeHttpResponse;
import com.phonepe.sdk.javasdk.transaction.init.models.InitResponse;
import com.phonepe.sdk.javasdk.transaction.init.models.enums.RedirectType;
import lombok.extern.slf4j.Slf4j;
import okhttp3.ConnectionPool;
import okhttp3.ConnectionSpec;
import okhttp3.Dispatcher;
import okhttp3.Interceptor;
import okhttp3.MediaType;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.ResponseBody;

import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.SSLSession;
import java.io.IOException;
import java.util.Collections;
import java.util.concurrent.TimeUnit;

@Slf4j
public class PhonePeHttpClientFactory {

  public static OkHttpClient buildOkHttpClient(final HttpClientConfig httpClientConfig) {

    Preconditions.checkNotNull(httpClientConfig);
    return createClient(httpClientConfig);
  }

  private static OkHttpClient createClient(final HttpClientConfig httpClientConfig) {

    int connections = httpClientConfig.getConnections();
    connections = connections == 0 ? 10 : connections;

    int idleTimeOutSeconds = httpClientConfig.getIdleTimeOutSeconds();
    idleTimeOutSeconds = idleTimeOutSeconds == 0 ? 30 : idleTimeOutSeconds;

    int connTimeout = httpClientConfig.getConnectTimeoutMs();
    connTimeout = connTimeout == 0 ? 10000 : connTimeout;

    int opTimeout = httpClientConfig.getOpTimeoutMs();
    opTimeout = opTimeout == 0 ? 10000 : opTimeout;

    Dispatcher dispatcher = new Dispatcher();
    dispatcher.setMaxRequests(connections);
    dispatcher.setMaxRequestsPerHost(connections);

    ConnectionSpec connectionSpec = httpClientConfig.getEndpoint().isSecured() ?
                                    new ConnectionSpec.Builder(ConnectionSpec.MODERN_TLS)
                                                  .allEnabledTlsVersions()
                                                  .allEnabledCipherSuites()
                                                  .build() : null;

    OkHttpClient.Builder clientBuilder = new OkHttpClient.Builder()
            .addNetworkInterceptor(debitRedirectHandler())
            .followRedirects(false)
            .followSslRedirects(false)
            .retryOnConnectionFailure(true)
            .connectionPool(new ConnectionPool(connections, idleTimeOutSeconds, TimeUnit.SECONDS))
            .connectTimeout(connTimeout, TimeUnit.MILLISECONDS)
            .readTimeout(opTimeout, TimeUnit.MILLISECONDS)
            .writeTimeout(opTimeout, TimeUnit.MILLISECONDS)
            .dispatcher(dispatcher);

    if(connectionSpec != null){
      clientBuilder.connectionSpecs(Collections.singletonList(connectionSpec));
    }

    // TODO: Check if this can be or needs to be set to OkHostnameVerifier
    // TODO: or if we can skip setting this to use the default configuration.
    clientBuilder.hostnameVerifier(
            new HostnameVerifier() {
              @Override
              public boolean verify(String hostname, SSLSession session) {
                return true;
              }
            });

    return clientBuilder.build();
  }

  private static Interceptor debitRedirectHandler(){
    return new Interceptor() {
      @Override
      public Response intercept(Chain chain) throws IOException {
        Request request = chain.request();
        Response response = chain.proceed(request);
        String requestPath = request.url().url().getPath();
        if(response.isRedirect() && (requestPath.contains("/v1/debit") || requestPath.contains("/v3/debit"))){

          InitResponse initResponse = InitResponse.builder()
                      .redirectType(RedirectType.WEB)
                      .redirectURL(response.header("location"))
                      .build();
          PhonePeHttpResponse<InitResponse> phonePeHttpResponse = PhonePeHttpResponse.<InitResponse>builder()
                                                                                     .success(true)
                                                                                     .message("SUCCESS")
                                                                                     .code("200")
                                                                                     .data(initResponse)
                                                                                     .build();

          return response.newBuilder()
                  .body(ResponseBody.create(MediaType.parse("application/json"),
                                            new ObjectMapper().writeValueAsBytes(phonePeHttpResponse)))
                  .code(200)
                  .build();
        }
        return response;
      }
    };
  }
}

==> java-sdk-1.0.0-20200723.085625-64-sources.jar: com/phonepe/sdk/javasdk/http/PhonePeHttpClientFactory.java <==
package com.phonepe.sdk.javasdk.http;

import com.google.common.base.Preconditions;
import com.phonepe.sdk.javasdk.config.models.HttpClientConfig;
import com.phonepe.sdk.javasdk.http.models.PhonePeHttpResponse;
import com.phonepe.sdk.javasdk.transaction.init.models.InitResponse;
import com.phonepe.sdk.javasdk.transaction.init.models.enums.RedirectType;
import com.phonepe.sdk.javasdk.utils.MapperUtils;
import lombok.extern.slf4j.Slf4j;
import okhttp3.ConnectionPool;
import okhttp3.ConnectionSpec;
import okhttp3.Dispatcher;
import okhttp3.Interceptor;
import okhttp3.MediaType;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okhttp3.internal.tls.OkHostnameVerifier;

import java.io.IOException;
import java.util.Collections;
import java.util.concurrent.TimeUnit;

@Slf4j
public class PhonePeHttpClientFactory {

  public static OkHttpClient buildOkHttpClient(final HttpClientConfig httpClientConfig) {

    Preconditions.checkNotNull(httpClientConfig);
    return createClient(httpClientConfig);
  }

  private static OkHttpClient createClient(final HttpClientConfig httpClientConfig) {

    int connections = httpClientConfig.getConnections();
    int idleTimeOutSeconds = httpClientConfig.getIdleTimeOutSeconds();
    int connTimeout = httpClientConfig.getConnectTimeoutMs();
    int opTimeout = httpClientConfig.getOpTimeoutMs();

    Dispatcher dispatcher = new Dispatcher();
    dispatcher.setMaxRequests(connections);
    dispatcher.setMaxRequestsPerHost(connections);

    ConnectionSpec connectionSpec = httpClientConfig.getEndpoint().isSecured() ?
                                    new ConnectionSpec.Builder(ConnectionSpec.MODERN_TLS)
                                                  .allEnabledTlsVersions()
                                                  .allEnabledCipherSuites()
                                                  .build() : null;

    OkHttpClient.Builder clientBuilder = new OkHttpClient.Builder()
            .addNetworkInterceptor(debitRedirectHandler())
            .followRedirects(false)
            .followSslRedirects(false)
            .retryOnConnectionFailure(true)
            .connectionPool(new ConnectionPool(connections, idleTimeOutSeconds, TimeUnit.SECONDS))
            .connectTimeout(connTimeout, TimeUnit.MILLISECONDS)
            .readTimeout(opTimeout, TimeUnit.MILLISECONDS)
            .writeTimeout(opTimeout, TimeUnit.MILLISECONDS)
            .dispatcher(dispatcher);

    if(connectionSpec != null){
      clientBuilder.connectionSpecs(Collections.singletonList(connectionSpec));
    }
    clientBuilder.hostnameVerifier(OkHostnameVerifier.INSTANCE);
    return clientBuilder.build();
  }

  private static Interceptor debitRedirectHandler(){
    return new Interceptor() {
      @Override
      public Response intercept(Chain chain) throws IOException {
        Request request = chain.request();
        Response response = chain.proceed(request);
        String requestPath = request.url().url().getPath();
        if(response.isRedirect() && (requestPath.contains("/v1/debit") || requestPath.contains("/v3/debit"))){

          InitResponse initResponse = InitResponse.builder()
                      .redirectType(RedirectType.WEB)
                      .redirectURL(response.header("location"))
                      .build();
          PhonePeHttpResponse<InitResponse> phonePeHttpResponse = PhonePeHttpResponse.<InitResponse>builder()
                                                                                     .success(true)
                                                                                     .message("SUCCESS")
                                                                                     .code("200")
                                                                                     .data(initResponse)
                                                                                     .build();

          return response.newBuilder()
                  .body(ResponseBody.create(MediaType.parse("application/json"),
                                            MapperUtils.getMapper().writeValueAsBytes(phonePeHttpResponse)))
                  .code(200)
                  .build();
        }
        return response;
      }
    };
  }
}
